import _extends from "@babel/runtime/helpers/extends";

/**
 * File: /src/components/Spinner/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 05-09-2022 22:44:37
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* eslint-disable @typescript-eslint/no-non-null-assertion,@typescript-eslint/no-explicit-any */
import React from "react";
import { Easing } from "react-native-reanimated";
import { Svg, Circle } from "react-native-svg";
import { styled } from "dripsy";
import { useAutoContrast } from "@risserlabs/auto-contrast";
import { Box } from "../Box";
const themeKey = "variants";
const defaultStyle = {
  color: "primary",
  overflow: "visible"
};
const defaultBoxStyle = {
  justifyContent: "center",
  alignItems: "center",
  alignSelf: "flex-start"
};
const StyledSvg = styled(Svg, {
  themeKey
})(defaultStyle);
const StyledBox = styled(Box, {
  themeKey
})(_ref => {
  let {
    size
  } = _ref;
  return { ...defaultStyle,
    ...defaultBoxStyle,
    width: size,
    height: size
  };
});
export const Spinner = props => {
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  const r = 16 - props.strokeWidth;
  const C = 2 * r * Math.PI;
  const offset = C - 1 / 4 * C;
  const svgProps = {
    fill: "none",
    height: props.size,
    stroke: "currentColor",
    strokeWidth: props.strokeWidth,
    viewBox: "0 0 32 32",
    width: props.size,
    style: {
      color: sx.color
    }
  };
  return /*#__PURE__*/React.createElement(StyledBox, _extends({}, props, {
    sx: sx
  }), /*#__PURE__*/React.createElement(StyledSvg, _extends({}, svgProps, {
    style: {
      opacity: 1 / 8
    }
  }), /*#__PURE__*/React.createElement(Circle, {
    cx: 16,
    cy: 16,
    r: r
  })), /*#__PURE__*/React.createElement(Box, {
    from: {
      rotate: "0deg"
    },
    animate: {
      rotate: "360deg"
    },
    transition: {
      duration: props.duration,
      easing: Easing.linear,
      loop: true,
      repeatReverse: false,
      type: "timing"
    },
    style: {
      borderRadius: 9999,
      overflow: "hidden",
      position: "absolute"
    }
  }, /*#__PURE__*/React.createElement(StyledSvg, svgProps, /*#__PURE__*/React.createElement(Circle, {
    cx: 16,
    cy: 16,
    r: r,
    strokeDasharray: C,
    strokeDashoffset: offset
  }))));
};
Spinner.defaultProps = {
  duration: 500,
  size: 48,
  strokeWidth: 4
};
//# sourceMappingURL=index.js.map